@@ -14,3 +14,9 @@ print(a1)
 
 a1.extend(array.array('I', [5]))
 print(a1)
+
+a1.extend([6, 7])
+print(a1)
+
+a1.extend(i for i in (8, 9))
+print(a1)
